@@ -1,12 +1,25 @@
-.noGenerics <- TRUE
-
-.onUnload <- function(libpath)
-    library.dynam.unload("tree", libpath)
-
 #
-#  tree/R/treemisc.R by B. D. Ripley
+#  tree/R/treemisc.R Copyright (C) 1994-2005 B. D. Ripley
 #  miscellaneous support routines for tree.
 #
+#  This program is free software; you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation; either version 2 or 3 of the License
+#  (at your option).
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  A copy of the GNU General Public License is available at
+#  http://www.r-project.org/Licenses/
+#
+
+
+.noGenerics <- TRUE
+
+.onUnload <- function(libpath) library.dynam.unload("tree", libpath)
 
 cv.tree <- function(object, rand, FUN = prune.tree, K = 10, ...)
 {
